@@ -3,6 +3,7 @@ import RolesConstants from '../constants/RolesConstants';
 import MistralApiService from '../services/MistralApiService';
 import MistralApiErrorHandler from '../services/MistralApiErrorHandler';
 import MistralConstants from '../constants/MistralConstants';
+import logger from '../services/logger';
 
 export default {
   fetchRoles(planName) {
@@ -13,7 +14,7 @@ export default {
       .then((response) => {
         dispatch(this.fetchRolesSuccess(JSON.parse(response.output).result));
       }).catch((error) => {
-        console.error('Error in RolesAction.fetchRoles', error.stack || error); //eslint-disable-line no-console
+        logger.error('Error in RolesAction.fetchRoles', error.stack || error);
         dispatch(this.fetchRolesFailed());
         let errorHandler = new MistralApiErrorHandler(error);
         errorHandler.errors.forEach((error) => {
