@@ -1,5 +1,6 @@
-import React from 'react';
+import { defineMessages, injectIntl, FormattedMessage } from 'react-intl';
 import ImmutablePropTypes from 'react-immutable-proptypes';
+import React from 'react';
 
 import DeploymentSuccess from './DeploymentSuccess';
 import DeploymentFailure from './DeploymentFailure';
@@ -8,11 +9,21 @@ import Link from '../ui/Link';
 import Loader from '../ui/Loader';
 import { stackStates } from '../../constants/StacksConstants';
 
-export const DeployStep = ({ currentPlan, currentStack, currentStackResources,
-                             currentStackResourcesLoaded, currentStackDeploymentProgress,
-                             deleteStack, deployPlan, fetchStackResource, fetchStackEnvironment,
-                             isRequestingStackDelete, runPostDeploymentValidations,
-                             stacksLoaded }) => {
+const messages = defineMessages({
+  validateAndDeploy: {
+    id: 'DeployStep.validateAndDeploy',
+    defaultMessage: 'Validate and Deploy'
+  },
+  requestingDeploy: {
+    id: 'DeployStep.requestingDeploy',
+    defaultMessage: 'Requesting a deploy...'
+  }
+});
+
+const DeployStep = ({ currentPlan, currentStack, currentStackResources, currentStackResourcesLoaded,
+                      currentStackDeploymentProgress, deleteStack, deployPlan, fetchStackResource,
+                      fetchStackEnvironment, intl, isRequestingStackDelete, stacksLoaded }) => {
+
   if (!currentStack || currentStack.stack_status === stackStates.DELETE_COMPLETE) {
     return (
       <Loader loaded={stacksLoaded}>
@@ -20,10 +31,11 @@ export const DeployStep = ({ currentPlan, currentStack, currentStackResources,
               disabled={currentPlan.isRequestingPlanDeploy}
               to="/deployment-plan/deployment-detail">
           <Loader loaded={!currentPlan.isRequestingPlanDeploy}
-                  content="Requesting a deploy..."
+                  content={intl.formatMessage(messages.requestingDeploy)}
                   component="span"
                   inline>
-            <span className="fa fa-cloud-upload"/> Validate and Deploy
+            <span className="fa fa-cloud-upload"/> <FormattedMessage
+                                                     {...messages.validateAndDeploy}/>
           </Loader>
         </Link>
       </Loader>
@@ -43,8 +55,7 @@ export const DeployStep = ({ currentPlan, currentStack, currentStackResources,
                          isRequestingStackDelete={isRequestingStackDelete}
                          deleteStack={deleteStack}
                          fetchStackResource={fetchStackResource}
-                         fetchStackEnvironment={fetchStackEnvironment}
-                         runPostDeploymentValidations={runPostDeploymentValidations}/>
+                         fetchStackEnvironment={fetchStackEnvironment} />
     );
   } else {
     return (
@@ -65,7 +76,9 @@ DeployStep.propTypes = {
   deployPlan: React.PropTypes.func.isRequired,
   fetchStackEnvironment: React.PropTypes.func.isRequired,
   fetchStackResource: React.PropTypes.func.isRequired,
+  intl: React.PropTypes.object,
   isRequestingStackDelete: React.PropTypes.bool.isRequired,
-  runPostDeploymentValidations: React.PropTypes.func.isRequired,
   stacksLoaded: React.PropTypes.bool.isRequired
 };
+
+export default injectIntl(DeployStep);
