@@ -8,6 +8,10 @@ const messages = defineMessages({
     id: 'PXEAndSSHDriverFields.addr_title',
     defaultMessage: 'SSH IP Address or FQDN'
   },
+  port_title: {
+    id: 'PXEAndSSHDriverFields.port_title',
+    defaultMessage: 'SSH Port'
+  },
   user_title: {
     id: 'PXEAndSSHDriverFields.user_title',
     defaultMessage: 'SSH User'
@@ -21,10 +25,13 @@ const messages = defineMessages({
 class PXEAndSSHDriverFields extends React.Component {
   render() {
     return (
-      <DriverFields {...this.props}
-                    addr_title={this.props.intl.formatMessage(messages.addr_title)}
-                    user_title={this.props.intl.formatMessage(messages.user_title)}
-                    pwd_title={this.props.intl.formatMessage(messages.pwd_title)} />
+      <DriverFields
+        {...this.props}
+        addr_title={this.props.intl.formatMessage(messages.addr_title)}
+        user_title={this.props.intl.formatMessage(messages.user_title)}
+        port_title={this.props.intl.formatMessage(messages.port_title)}
+        pwd_title={this.props.intl.formatMessage(messages.pwd_title)}
+      />
     );
   }
 }
